@@ -17,7 +17,7 @@ clonemap:
    dest: ${GIT_PROJECT_DIR}/requirements
 EOF
     /usr/zuul-env/bin/zuul-cloner -m /tmp/clonemap --workspace "$(pwd)" \
-        --cache-dir /opt/git git://git.openstack.org \
+        --cache-dir /opt/git https://git.openstack.org \
         openstack/kolla openstack/requirements
 }
 
@@ -44,20 +44,31 @@ EOF
         GATE_IMAGES+=",ceph,cinder"
     fi
 
+    if [[ $ACTION == "zun" ]]; then
+        GATE_IMAGES+=",zun,kuryr"
+    fi
+
+    # Use the kolla-ansible tag rather than the kolla tag, since this is what
+    # kolla-ansible will use by default.
+    TAG=$(python -c "import pbr.version; print(pbr.version.VersionInfo('kolla-ansible'))")
     cat <<EOF | sudo tee /etc/kolla/kolla-build.conf
 [DEFAULT]
 include_header = /etc/kolla/header
 namespace = lokolla
 base = ${BASE_DISTRO}
 install_type = ${INSTALL_TYPE}
+tag = ${TAG}
 profile = gate
 registry = 127.0.0.1:4000
 push = true
+logs_dir = /tmp/logs/build
 
 [profiles]
 gate = ${GATE_IMAGES}
 EOF
 
+mkdir -p /tmp/logs/build
+
     if [[ "${DISTRO}" == "Debian" ]]; then
         # Infra does not sign their mirrors so we ignore gpg signing in the gate
         echo "RUN echo 'APT::Get::AllowUnauthenticated \"true\";' > /etc/apt/apt.conf" | sudo tee -a /etc/kolla/header
@@ -86,7 +97,10 @@ function setup_ansible {
     RAW_INVENTORY=/etc/kolla/inventory
 
     # TODO(SamYaple): Move to virtualenv
-    sudo -H pip install -U "ansible>=2.4" "docker>=2.0.0" "python-openstackclient" "python-neutronclient" "ara" "cmd2<0.9.0"
+    sudo -H pip install -U "ansible>=2.4" "docker>=2.0.0" "python-openstackclient" "ara" "cmd2<0.9.0"
+    if [[ $ACTION == "zun" ]]; then
+        sudo -H pip install -U "python-zunclient"
+    fi
     detect_distro
 
     sudo mkdir /etc/ansible
@@ -124,7 +138,7 @@ function sanity_check {
     # https://bugs.launchpad.net/oslo.cache/+bug/1590779
     sudo docker restart memcached
     nova --debug service-list
-    neutron --debug agent-list
+    openstack --debug network agent list
     tools/init-runonce
     nova --debug boot --poll --image $(openstack image list | awk '/cirros/ {print $2}') --nic net-id=$(openstack network list | awk '/demo-net/ {print $2}') --flavor 1 kolla_boot_test
 
@@ -137,6 +151,12 @@ function sanity_check {
         cinder create --name test_volume 2
         openstack server add volume kolla_boot_test test_volume --device /dev/vdb
     fi
+    if echo $ACTION | grep -q "zun"; then
+        openstack --debug appcontainer service list
+        openstack --debug appcontainer host list
+        # TODO(hongbin): Run a Zun container and assert the container becomes
+        # Running
+    fi
 }
 
 function test_openstack {
